//This Stata "do" file runs the cross section models in 
//"A Rational Expectations Approach to Hedonic Price Regressions with Time-Varying Unobserved Product Attributes: The Price of Pollution// by Patrick Bajari, Jane Cooley, Kyoo il Kim, and Chris Timmins


//Generating variables

gen lnprice=log(price)
gen period=1 if yr<6
replace period=2 if yr>5 & yr<12
replace period=3 if yr>11

xi i.county_code
gen county2=_Icounty_co_2
gen county3=_Icounty_co_3
gen county4=_Icounty_co_4
gen county5=_Icounty_co_5
gen county6=_Icounty_co_6



//all pollutants
regress lnprice pmc soc ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(robust)
regress lnprice pmc soc ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(robust)
regress lnprice pmc soc ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(robust)

//PM10 only
regress lnprice pmc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(robust)
regress lnprice pmc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(robust)
regress lnprice pmc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(robust)

//SO2 only
regress lnprice soc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(robust)
regress lnprice soc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(robust)
regress lnprice soc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(robust)

//O3 only
regress lnprice ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(robust)
regress lnprice ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(robust)
regress lnprice ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(robust)

//all pollutants
regress lnprice pmc soc ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(cluster tract)
regress lnprice pmc soc ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(cluster tract)
regress lnprice pmc soc ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(cluster tract)

//PM10 only
regress lnprice pmc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(cluster tract)
regress lnprice pmc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(cluster tract)
regress lnprice pmc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(cluster tract)

//SO2 only
regress lnprice soc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(cluster tract)
regress lnprice soc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(cluster tract)
regress lnprice soc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(cluster tract)

//O3 only
regress lnprice ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==1, vce(cluster tract)
regress lnprice ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==2, vce(cluster tract)
regress lnprice ozc  lotsize sqft beds rooms baths yrblt county2 county3 county4 county5 county6 if period==3, vce(cluster tract)
