//This Stata "do" file runs the fixed effect models in 
//"A Rational Expectations Approach to Hedonic Price Regressions with Time-Varying Unobserved Product Attributes: The Price of Pollution
// by Patrick Bajari, Jane Cooley, Kyoo il Kim, and Chris Timmins


//Generating variables

gen dpmc=pmc2-pmc1
gen dsoc=soc2-soc1
gen dozc=ozc2-ozc1

gen lnprice2=log(price2)
gen lnprice1=log(price1)
gen dlnprice=lnprice2-lnprice1

gen indicate=d32+d31+d21
drop if indicate==0


//all pollutants
regress dlnprice d32 d31 d21 dpmc dsoc dozc d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(robust)

//PM10 only
regress dlnprice d32 d31 d21 dpmc  d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(robust)

//SO2 only
regress dlnprice d32 d31 d21 dsoc  d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(robust)

//O3 only
regress dlnprice d32 d31 d21 dozc  d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(robust)


//all pollutants
regress dlnprice d32 d31 d21 dpmc dsoc dozc d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(cluster tract)

//PM10 only
regress dlnprice d32 d31 d21 dpmc d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(cluster tract)

//SO2 only
regress dlnprice d32 d31 d21 dsoc d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(cluster tract)

//O3 only
regress dlnprice d32 d31 d21 dozc d32lotsize d31lotsize d21lotsize d32sqft d31sqft d21sqft d32beds d31beds d21beds d32baths d31baths d21baths d32rooms d31rooms d21rooms d32yrblt d31yrblt d21yrblt d32co2 d31co2 d21co2 d32co3 d31co3 d21co3 d32co4 d31co4 d21co4 d32co5 d31co5 d21co5 d32co6 d31co6 d21co6, vce(cluster tract)
